﻿using System;
using System.Data;
using System.Configuration;

using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;

using System.Data.OleDb;
using System.Collections.Generic;
using System.Data.SqlClient;
using System.IO;
using System.Text.RegularExpressions;


/// <summary>
/// Access 的摘要说明
/// 数据库操作类
/// Version 1.0.0.0
/// www.localshare.cn
/// 2013-02-01
/// </summary>
public class Access
{
    /// <summary>
    /// Access 数据类
    /// </summary>
    public Access()
    {
        //
        //TODO: 在此处添加构造函数逻辑
        //
    }

    private static string connString = System.Configuration.ConfigurationManager.ConnectionStrings["connString"].ConnectionString;

    public static string GetStringNum(string Content, int Num)
    {
        if (Content == null || Content == string.Empty || Content.Length < Num)
            return Content;

        char[] cArray = Content.ToCharArray();
        int iAlreadyNum = 0;
        int iOkLenNum = 0;
        foreach (char cH in cArray)
        {
            if (iAlreadyNum < Num * 2)
            {
                if (cH > 128)
                {
                    iAlreadyNum += 2;
                }
                else
                    iAlreadyNum++;
                iOkLenNum++;
            }
            else
                break;
        }
        Content = Content.Substring(0, iOkLenNum);
        return Content;
    }

    /// <summary>
    /// 返回受影响的行数 添加，删除 ，修改
    /// </summary>
    /// <param name="sql">sql</param>
    /// <param name="values">参数, null</param>
    /// <returns>count</returns>
    public static int ExecuteCount(String sql, OleDbParameter[] values)
    {
        int count = 0;
        using (OleDbConnection oleConn = new OleDbConnection(connString))
        {
            OleDbCommand oleComm = new OleDbCommand(sql, oleConn);
            oleComm.CommandType = CommandType.Text;
            if (values != null)
            {
                oleComm.Parameters.AddRange(values);
            }
            oleConn.Open();
            count = oleComm.ExecuteNonQuery();
        }
        return count;
    }


    /// <summary>
    /// 返回一个int
    /// </summary>
    /// <param name="sql">sql</param>
    /// <param name="values">参数, null</param>
    /// <returns>count</returns>
    public static int ExecuteInt(String sql, OleDbParameter[] values)
    {
        int count = 0;
        using (OleDbConnection oleConn = new OleDbConnection(connString))
        {
            OleDbCommand oleComm = new OleDbCommand(sql, oleConn);
            oleComm.CommandType = CommandType.Text;
            if (values != null)
            {
                oleComm.Parameters.AddRange(values);
            }
            oleConn.Open();
            String str = Convert.ToString(oleComm.ExecuteScalar());
            if (!String.IsNullOrEmpty(str))
            {
                count = int.Parse(str);
            }
        }
        return count;
    }


    /// <summary>
    /// 返回一个String
    /// </summary>
    /// <param name="sql">sql</param>
    /// <param name="values">参数, null</param>
    /// <returns>String</returns>
    public static String ExecuteString(String sql, OleDbParameter[] values)
    {
        String str = "";
        using (OleDbConnection oleConn = new OleDbConnection(connString))
        {
            OleDbCommand oleComm = new OleDbCommand(sql, oleConn);
            oleComm.CommandType = CommandType.Text;
            if (values != null)
            {
                oleComm.Parameters.AddRange(values);
            }
            oleConn.Open();
            Object obj = oleComm.ExecuteScalar();
            if (obj != null)
            {
                str = obj.ToString();
            }
        }
        return str;
    }


    /// <summary>
    /// 返回DataTable
    /// </summary>
    /// <param name="sql">sql</param>
    /// <param name="values">参数 ,null</param>
    /// <returns>DataTable</returns>
    public static DataTable ExecuteDataTable(String sql, OleDbParameter[] values)
    {
        DataTable dt = new DataTable();
        using (OleDbConnection oleConn = new OleDbConnection(connString))
        {
            OleDbCommand oleComm = new OleDbCommand(sql, oleConn);
            oleComm.CommandType = CommandType.Text;
            if (values != null)
            {
                oleComm.Parameters.AddRange(values);
            }
            oleConn.Open();
            OleDbDataReader oleReader = oleComm.ExecuteReader();
            dt.Load(oleReader);
        }
        return dt;
    }

    /// <summary>
    /// 返回DataSet
    /// </summary>
    /// <param name="sql">sql</param>
    /// <param name="values">参数,null</param>
    /// <returns>DataSet</returns>
    public static DataSet ExecuteDataSet(String sql, OleDbParameter[] values)
    {
        DataSet ds = new DataSet();
        using (OleDbDataAdapter da = new OleDbDataAdapter(sql, connString))
        {
            if (values != null)
            {
                da.SelectCommand.Parameters.AddRange(values);
            }
            da.Fill(ds);
        }
        return ds;
    }

    /// <summary>
    /// 事务返回sql语句数
    /// </summary>
    /// <param name="listSql">listSql  new List<String>()</param>
    /// <param name="values">listValue  new List<OleDbParameter[]>()</param>
    /// <returns>count</returns>
    public static int ExecuteTransaction(List<String> listSql, List<OleDbParameter[]> values)
    {
        int count = 0;
        using (OleDbConnection oleConn = new OleDbConnection(connString))
        {
            oleConn.Open();
            OleDbTransaction oleTran = oleConn.BeginTransaction();
            try
            {
                for (int i = 0; i < listSql.Count; i++)
                {
                    OleDbCommand oleComm = new OleDbCommand();
                    oleComm.Connection = oleConn;
                    oleComm.Transaction = oleTran;
                    oleComm.CommandText = listSql[i];
                    OleDbParameter[] value = values[i];
                    if (value != null)
                    {
                        oleComm.Parameters.AddRange(value);
                    }
                    count += oleComm.ExecuteNonQuery();
                }
                oleTran.Commit();
            }
            catch (SqlException ex)
            {
                oleTran.Rollback();
            }
            finally
            {
                oleTran.Dispose();
            }
        }
        return count;
    }


    //////////// 分页 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    /// <summary>
    /// 查询列表分页
    /// </summary>
    /// <param name="sql">sql</param>
    /// <param name="values">参数,null</param>
    /// <param name="AspNetPager1">AspNetPager1</param>
    /// <param name="currentIndex">当前页的索引</param>
    /// <returns>PagedDataSource</returns>
    public static PagedDataSource ExecutePagedDataSource(String sql, OleDbParameter[] values, Wuqi.Webdiyer.AspNetPager AspNetPager1, int currentIndex)
    {
        DataTable dt = ExecuteDataSet(sql, values).Tables[0];
        PagedDataSource datasource = GetPageDataSource(AspNetPager1, currentIndex, dt);
        return datasource;
    }

    /// <summary>
    /// 返回PagedDataSource
    /// </summary>
    /// <param name="AspNetPager1">AspNetPager1</param>
    /// <param name="currentIndex">当前页的索引</param>
    /// <param name="dt">dataTable</param>
    /// <returns>PagedDataSource</returns>
    public static PagedDataSource GetPageDataSource(Wuqi.Webdiyer.AspNetPager AspNetPager1, int currentIndex, DataTable dt)
    {
        PagedDataSource source = new PagedDataSource();
        AspNetPager1.RecordCount = dt.Rows.Count;
        source.DataSource = dt.DefaultView;
        source.AllowPaging = true;
        source.CurrentPageIndex = currentIndex;
        source.PageSize = AspNetPager1.PageSize;
        return source;
    }

    /// <summary>
    /// SQL 语句分页查询
    /// </summary>
    /// <param name="pageSize">每页记录数</param>
    /// <param name="pageNumber">当前页数</param>
    /// <param name="tableName">表名称 或 表查询语句</param>
    /// <param name="sort">排序 id desc</param>
    /// <returns>DataTable</returns>
    public static DataTable ExecuteTableDataSource(int pageSize, int pageNumber, String tableName, String sort)
    {
        String sql = String.Format("select top {0} * from "+tableName+" where id >= (select max(id) from (select top {1} id from "+tableName+"  order by id asc) as T ) "
           + " order by " + sort , pageSize, pageSize * (pageNumber - 1) + 1);
        return ExecuteDataTable(sql, null);
    }
}
